==> megamenu_framework-7.x-1.0.tar.gz: megamenu_framework/README.md <==
CONTENTS OF THIS FILE
---------------------
 * Introduction
 * Requirements
 * Recommended modules
 * Installation
 * Configuration
 * Troubleshooting
 * Maintainers

INTRODUCTION
------------
This module provides a flexible framework for building a megamenu. Unlike most other Megamenu modules this one does not attempt to generate a finished menu, which can then be difficult to customize. Instead it provides the bones of a megamenu with almost no styling, making it easy to customize.

If you're looking for a plug and play solution, this is not the module for you. But if you're looking for an easy way to roll your own with full styling flexibility, this is what you're  looking for.

 * To submit bug reports and feature suggestions, or to track changes:
   https://drupal.org/project/issues/megamenu_framework


DEPENDENCIES
------------
This module requires the following modules:

 * Block (Drupal core)
 * Regions (https://drupal.org/project/regions)


RECOMMENDED MODULES
-------------------
* Menu Blocks (https://www.drupal.org/project/menu_blocks):
   This module provides configurable blocks of menu links with advanced features.


INSTALLATION
------------
 * Install as you would normally install a contributed Drupal module. See:
   https://drupal.org/documentation/install/modules-themes/modules-7 for further information.


CONFIGURATION
-------------
The module will create a theme region, "Megamenu Framework" and a block, "Megamenu". It will automatically assign this block to the region. DO NOT ADD ANYTHING ELSE to the "Megamenu Framework" region. It should remain dedicated to only the auto-assigned "Megamenu" block.

You will need to add this  region to the appropriate template location in your site's theme. The region's machine name is "megamenu_framework" so for example, in your page.tpl.php...

```
<div id="megamenu-wrapper">
  <div class="section clearfix">
    <?php print render($page['megamenu_framework']); ?>
  </div>
</div>
```

This should be the only thing you need to add to your theme files.

NOTE: You are not required to use this region. If you like you can move the Megamenu block to any region of your choosing and skip the template alteration outlined above. I just chose to isolate Megamenu Framework's output from the rest of the site by default.

On the module's admin page you'll see two tools. The first one allows you to create "categories". These are the main menu buttons and matching pulldowns. You specify the category and the number of columns its matching pulldown will have. The module will generate the Theme Regions for each one. You'll build your megamenu by adding blocks to the appropriate regions. On your Blocks admin page You'll see regions for each megagmenu column in each category.

For example: "Megamenu pulldown: My Category Title -- columnX"

Simply assign blocks to these to build your Megamenu. Any block can be inserted, but you'll probably make heavy use of "Menu Blocks".

DO NOT add these regions to your templates. Their content will be automatically added to the megamenu_framework region mentioned above.


##### BLOCK PLACEMENT #####
This module supports placing block content with both the Core Block UI and the Context Module. While both methods can be used at the same time, their content cannot be intermingled. So choose with one you want to appear at the top of each region.


##### CLICK EVENT EXCLUSIONS #####
There are two types of events that will trigger the pulldowns. Hovering on a main menu item and clicking on one.  If you select "click" you'll get an optional form on the admin page for excluding DOM objects from click events. The megamenu's default behavior is to open pulldowns when the main menu items are clicked. After that, clicking ANYWHERE will close the pulldowns.

But what if there's something you don't want to react to a mouseclick. For example if you put a search box in the megamenu. You don't want the menu to close when a user clicks on the input field.

That's what this configuration is for. Enter a jQuery identification string here for the page element in question and it will be exempted from the click event. One ID string per line.

##### DATA LOSS #####
You'll see a number of warnings in the help text about blocks being disabled on certain admin operations. THEY WILL NOT BE DELETED. This module does not touch your content data and won't damage or destroy it. But once disabled, the blocks won't re-appear until you manually re-assign them to another region.


TROUBLESHOOTING
---------------
A CSS override is not working.
 * There are a handful of styles that are defined by the module, if you have trouble overriding something, just include "!important" in your CSS declaration.

The Megamenu is not printing to the page.
 * Make sure you are printing the "meganenu_framework" region to the appropriate template.
 * Make sure the "Megamenu" block is assigned to the "Megamenu Framework" region.
 * Make sure you've assigned content to the auto generated category/column regions.


MAINTAINERS
-----------
Current maintainers:
 * Chris Desautels (cdesautels) - https://www.drupal.org/user/187691


This project has been sponsored by:

##### AQUILENT (on behalf of NIAID) #####

![Aquilent](inc/Aquilent_Tag_H_RGB.png)
Aquilent is the leading provider of Digital Services, DevOps & Agile, and Cloud Services shaping the next generation of technology for the federal government.
Visit http://www.aquilent.com/ for more information.


##### NIAID #####
The National Institute of Allergy and Infectious Diseases (NIAID) conducts and supports basic and applied research to better understand, treat, and ultimately prevent infectious, immunologic, and allergic diseases. 
Visit http://www.niaid.nih.gov/ for more information.

==> megamenu_framework-7.x-1.1.tar.gz: megamenu_framework/README.md <==
CONTENTS OF THIS FILE
---------------------
 * Introduction
 * Dependencies
 * Recommended modules
 * Installation
 * Configuration
 * Troubleshooting
 * Maintainers

INTRODUCTION
------------
This module provides a flexible framework for building a megamenu. Unlike most other Megamenu modules this one does not attempt to generate a finished menu, which can then be difficult to customize. Instead it provides the bones of a megamenu with almost no styling, making it easy to customize.

If you're looking for a plug and play solution, this is not the module for you. But if you're looking for an easy way to roll your own with full styling flexibility, this is what you're  looking for.

 * To submit bug reports and feature suggestions, or to track changes:
   https://drupal.org/project/issues/megamenu_framework


DEPENDENCIES
------------
This module requires the following modules:

 * Block (Drupal core)
 * Regions (https://drupal.org/project/regions)


RECOMMENDED MODULES
-------------------
* Menu Blocks (https://www.drupal.org/project/menu_blocks):
   This module provides configurable blocks of menu links with advanced features.


INSTALLATION
------------
 * Install as you would normally install a contributed Drupal module. See:
   https://drupal.org/documentation/install/modules-themes/modules-7 for further information.


CONFIGURATION
-------------
The module will create a theme region, "Megamenu Framework" and a block, "Megamenu". It will automatically assign this block to the region. DO NOT ADD ANYTHING ELSE to the "Megamenu Framework" region. It should remain dedicated to only the auto-assigned "Megamenu" block.

You will need to add this  region to the appropriate template location in your site's theme. The region's machine name is "megamenu_framework" so for example, in your page.tpl.php...

```
<div id="megamenu-wrapper">
  <div class="section clearfix">
    <?php print render($page['megamenu_framework']); ?>
  </div>
</div>
```

This should be the only thing you need to add to your theme files.

NOTE: You are not required to use this region. If you like you can move the Megamenu block to any region of your choosing and skip the template alteration outlined above. I just chose to isolate Megamenu Framework's output from the rest of the site by default.

On the top of module's admin page are the "categories" (click on "Add Category" at the top right to start). These are the main menu buttons and matching pulldowns. You specify the category and the number of columns its matching pulldown will have. The module will generate the Theme Regions for each one. You'll build your megamenu by adding blocks to the appropriate regions. On your Blocks admin page You'll see regions for each megagmenu column in each category.

For example: "Megamenu pulldown: My Category Title -- columnX"

Simply assign blocks to these to build your Megamenu. Any block can be inserted, but you'll probably make heavy use of "Menu Blocks".

DO NOT add these regions to your templates. Their content will be automatically added to the "Megamenu" block mentioned above.


##### BLOCK PLACEMENT #####
This module supports placing block content with both the Core Block UI and the Context Module. While both methods can be used at the same time, their content cannot be intermingled. So choose with one you want to appear at the top of each region.


##### TRIGGERING EVENT #####
Select the type of event that triggers the megamenu. If you select "hover" then each category provides for an optional url (for the main menu button).


##### CLICK EVENT EXCLUSIONS #####
If you set the triggering event to "click" you'll get an optional form on the admin page for excluding DOM objects from click events. The megamenu's default behavior is to open pulldowns when the main menu items are clicked. After that, clicking ANYWHERE will close the pulldowns.

But what if there's something you don't want to react to a mouseclick. For example if you put a search box in the megamenu. You don't want the menu to close when a user clicks on the input field.

That's what this configuration is for. Enter a jQuery identification string here for the page element in question and it will be exempted from the click event. One ID string per line.

##### DATA LOSS #####
You'll see a number of warnings in the help text about blocks being disabled on certain admin operations. THEY WILL NOT BE DELETED. This module does not touch your content data and won't damage or destroy it. But once disabled, the blocks won't re-appear until you manually re-assign them to another region.


TROUBLESHOOTING
---------------
A CSS override is not working.
 * There are a handful of styles that are defined by the module, if you have trouble overriding something, just include "!important" in your CSS declaration.

The Megamenu is not printing to the page.
 * Make sure you are printing the "meganenu_framework" region to the appropriate template.
 * Make sure the "Megamenu" block is assigned to the "Megamenu Framework" region.
 * Make sure you've assigned content to the auto generated category/column regions.


MAINTAINERS
-----------
Current maintainers:
 * Chris Desautels (cdesautels) - https://www.drupal.org/user/187691


This project has been sponsored by:

##### AQUILENT (on behalf of NIAID) #####

![Aquilent](inc/Aquilent_Tag_H_RGB.png)
Aquilent is the leading provider of Digital Services, DevOps & Agile, and Cloud Services shaping the next generation of technology for the federal government.
Visit http://www.aquilent.com/ for more information.


##### NIAID #####
The National Institute of Allergy and Infectious Diseases (NIAID) conducts and supports basic and applied research to better understand, treat, and ultimately prevent infectious, immunologic, and allergic diseases.
Visit http://www.niaid.nih.gov/ for more information.
